@@ -54,7 +54,7 @@ from hypothesis.reporting import report, verbose_report, current_verbosity
 from hypothesis.statistics import note_engine_for_statistics
 from hypothesis.internal.compat import ceil, hbytes, qualname, \
     str_to_bytes, benchmark_time, get_type_hints, getfullargspec, \
-    encoded_filepath, bad_django_TestCase
+    int_from_bytes, encoded_filepath, bad_django_TestCase
 from hypothesis.internal.coverage import IN_COVERAGE_TESTS
 from hypothesis.utils.conventions import infer, not_set
 from hypothesis.internal.escalation import is_hypothesis_file, \
@@ -115,8 +115,10 @@ def seed(seed):
     May be any hashable object. No exact meaning for seed is provided
     other than that for a fixed seed value Hypothesis will try the same
     actions (insofar as it can given external sources of non-
-    determinism. e.g. timing and hash randomization). Overrides the
-    derandomize setting if it is present.
+    determinism. e.g. timing and hash randomization).
+
+    Overrides the derandomize setting, which is designed to enable
+    deterministic builds rather than reproducing observed failures.
 
     """
     def accept(test):
@@ -298,7 +300,7 @@ def get_random_for_wrapped_test(test, wrapped_test):
         return Random(
             wrapped_test._hypothesis_internal_use_seed)
     elif settings.derandomize:
-        return Random(function_digest(test))
+        return Random(int_from_bytes(function_digest(test)))
     elif global_force_seed is not None:
         return Random(global_force_seed)
     else:
@@ -942,15 +944,15 @@ def given(*given_arguments, **given_kwargs):
             __tracebackhide__ = True
 
             if getattr(test, 'is_hypothesis_test', False):
-                note_deprecation((
+                note_deprecation(
                     'You have applied @given to a test more than once. In '
                     'future this will be an error. Applying @given twice '
                     'wraps the test twice, which can be extremely slow. A '
                     'similar effect can be gained by combining the arguments '
-                    'to the two calls to given. For example, instead of '
+                    'of the two calls to given. For example, instead of '
                     '@given(booleans()) @given(integers()), you could write '
                     '@given(booleans(), integers())'
-                ))
+                )
 
             settings = wrapped_test._hypothesis_internal_use_settings
 
@@ -1111,6 +1113,7 @@ def find(specifier, condition, settings=None, random=None, database_key=None):
     random = random or new_random()
     successful_examples = [0]
     last_data = [None]
+    last_repr = [None]
 
     def template_condition(data):
         with BuildContext(data):
@@ -1127,22 +1130,19 @@ def find(specifier, condition, settings=None, random=None, database_key=None):
 
         if settings.verbosity == Verbosity.verbose:
             if not successful_examples[0]:
-                report(lambda: u'Trying example %s' % (
-                    nicerepr(result),
-                ))
+                report(
+                    u'Tried non-satisfying example %s' % (nicerepr(result),))
             elif success:
                 if successful_examples[0] == 1:
-                    report(lambda: u'Found satisfying example %s' % (
-                        nicerepr(result),
-                    ))
+                    last_repr[0] = nicerepr(result)
+                    report(u'Found satisfying example %s' % (last_repr[0],))
                     last_data[0] = data
                 elif (
                     sort_key(hbytes(data.buffer)) <
                     sort_key(last_data[0].buffer)
-                ):
-                    report(lambda: u'Shrunk example to %s' % (
-                        nicerepr(result),
-                    ))
+                ) and nicerepr(result) != last_repr[0]:
+                    last_repr[0] = nicerepr(result)
+                    report(u'Shrunk example to %s' % (last_repr[0],))
                     last_data[0] = data
         if success and not data.frozen:
             data.mark_interesting()
